# Changelog

## 1.26.1 (2026-03-25)

Full Changelog: [v1.26.0...v1.26.1](https://github.com/deeprails/deeprails-sdk-python/compare/v1.26.0...v1.26.1)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([7b8f509](https://github.com/deeprails/deeprails-sdk-python/commit/7b8f509615bfca90d9fda54835a6e9fc6fafe3c3))
* **pydantic:** do not pass `by_alias` unless set ([15e3524](https://github.com/deeprails/deeprails-sdk-python/commit/15e3524e2f5905bd4b964d9be1d618027625ca8c))
* sanitize endpoint path params ([ec1e174](https://github.com/deeprails/deeprails-sdk-python/commit/ec1e174233b69cc75afb3b35c577f1803e3e4702))


### Chores

* **ci:** skip lint on metadata-only changes ([b2cc3b8](https://github.com/deeprails/deeprails-sdk-python/commit/b2cc3b82df63fcd3767f941a2b09a7992486001d))
* **internal:** tweak CI branches ([94869f0](https://github.com/deeprails/deeprails-sdk-python/commit/94869f0284fed13bd041f489cb8bcce45b1483e3))
* **internal:** update gitignore ([80bcbd8](https://github.com/deeprails/deeprails-sdk-python/commit/80bcbd87d9f6496b765711939d1b1f72f4b43e7d))

## 1.26.0 (2026-03-10)

Full Changelog: [v1.25.0...v1.26.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.25.0...v1.26.0)

### Features

* **api:** manual updates ([3a9248b](https://github.com/deeprails/deeprails-sdk-python/commit/3a9248b62b512ea6b5d3da1e7899d220045d2882))
* **api:** update run mode lists ([9edf003](https://github.com/deeprails/deeprails-sdk-python/commit/9edf00309e164155bd3cc849afb015ee61554f18))
* **client:** add custom JSON encoder for extended type support ([df85b76](https://github.com/deeprails/deeprails-sdk-python/commit/df85b76b2d636f312b1deb962bd13133fb58e1e6))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([3b4703a](https://github.com/deeprails/deeprails-sdk-python/commit/3b4703a253039eca1a4fab4a955726fc7aed0999))
* **ci:** upgrade `actions/github-script` ([79e5242](https://github.com/deeprails/deeprails-sdk-python/commit/79e524262dd19264b73732e6b8f4e3d3c0f6aa6c))
* format all `api.md` files ([b4fe705](https://github.com/deeprails/deeprails-sdk-python/commit/b4fe705ba309a1cac4e9d3abccda70b2eef850b5))
* **internal:** add request options to SSE classes ([bc54f7c](https://github.com/deeprails/deeprails-sdk-python/commit/bc54f7c4ddbfe0edee8b0d314cc9a04b8f130e38))
* **internal:** bump dependencies ([18b899d](https://github.com/deeprails/deeprails-sdk-python/commit/18b899d6e40a67b6af04ccc012fa240693ed775f))
* **internal:** fix lint error on Python 3.14 ([6335881](https://github.com/deeprails/deeprails-sdk-python/commit/63358810ebc67a7ecba269df661b9e2099dbb9b5))
* **internal:** make `test_proxy_environment_variables` more resilient ([f03efb2](https://github.com/deeprails/deeprails-sdk-python/commit/f03efb2cede995a4d6cef068d31ad4db9ef3c8e2))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([923d571](https://github.com/deeprails/deeprails-sdk-python/commit/923d571ef2d8f973e69e2909927b8fdec7de38ab))
* **internal:** remove mock server code ([4c64963](https://github.com/deeprails/deeprails-sdk-python/commit/4c6496303388d8996af9dfc2c9cab2d6539e3f1a))
* **test:** update skip reason message ([d095518](https://github.com/deeprails/deeprails-sdk-python/commit/d0955180f3936f0935bf6b868dac4a529ce4f833))
* update mock server docs ([7b7c379](https://github.com/deeprails/deeprails-sdk-python/commit/7b7c37926ebd2e1d7cdbf115965d76afe6d8a279))

## 1.25.0 (2026-01-20)

Full Changelog: [v1.24.0...v1.25.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.24.0...v1.25.0)

### Features

* **api:** manual updates ([8a77ac8](https://github.com/deeprails/deeprails-sdk-python/commit/8a77ac8272bfabc3b35122e3ff904440806398ed))
* **client:** add support for binary request streaming ([97e312c](https://github.com/deeprails/deeprails-sdk-python/commit/97e312c6c4ef77c2964558df9b748d435b084db8))


### Chores

* **internal:** codegen related update ([5f9d210](https://github.com/deeprails/deeprails-sdk-python/commit/5f9d2106b98ed3d6d0c403c30852cb96eab48d8b))
* **internal:** update `actions/checkout` version ([547dac2](https://github.com/deeprails/deeprails-sdk-python/commit/547dac2ac82bfabad9e70efa5af2ef3c6e0260a8))

## 1.24.0 (2025-12-23)

Full Changelog: [v1.23.0...v1.24.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.23.0...v1.24.0)

### Features

* **api:** add key improvements and analysis of failures ([1205e40](https://github.com/deeprails/deeprails-sdk-python/commit/1205e406077d94a1608e1274879fb9ebd8f80729))


### Bug Fixes

* use async_to_httpx_files in patch method ([1d3be39](https://github.com/deeprails/deeprails-sdk-python/commit/1d3be39067d612a9ad19c3f0252fcfad200232a5))


### Chores

* **internal:** add `--fix` argument to lint script ([288d8cb](https://github.com/deeprails/deeprails-sdk-python/commit/288d8cb1eea6162ca1ed8bd7a1d9d5d26a35defc))
* **internal:** add missing files argument to base client ([c54fdad](https://github.com/deeprails/deeprails-sdk-python/commit/c54fdadbcbe79e17853ee1c14b1825765bb84a6b))
* speedup initial import ([ca49036](https://github.com/deeprails/deeprails-sdk-python/commit/ca49036945d7e7fa6b8114adfa7bbf9d55df53ba))

## 1.23.0 (2025-12-15)

Full Changelog: [v1.22.0...v1.23.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.22.0...v1.23.0)

### Features

* **api:** add precision plus codex ([204731c](https://github.com/deeprails/deeprails-sdk-python/commit/204731c7e9e28d68ff45788fb4e266e2d3616d1a))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([6bafa1d](https://github.com/deeprails/deeprails-sdk-python/commit/6bafa1d574bcd57a7c7690eba5ca458dc1d258e7))


### Chores

* add missing docstrings ([3d9f4f7](https://github.com/deeprails/deeprails-sdk-python/commit/3d9f4f7a0b482b3435c6c101b0595c40517e393a))

## 1.22.0 (2025-12-07)

Full Changelog: [v1.21.0...v1.22.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.21.0...v1.22.0)

### Features

* **api:** Expand update endpoints ([9fd3448](https://github.com/deeprails/deeprails-sdk-python/commit/9fd3448b79013177b38d443ba67c553a44c779ae))
* **api:** manual updates ([a98dc53](https://github.com/deeprails/deeprails-sdk-python/commit/a98dc538b121e2a74631e7eaba78c89e9d206a2f))

## 1.21.0 (2025-12-07)

Full Changelog: [v1.20.0...v1.21.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.20.0...v1.21.0)

### Features

* **api:** added context_awareness and context ([ef1a752](https://github.com/deeprails/deeprails-sdk-python/commit/ef1a752f8426ac059c54830d34c98005538959aa))


### Bug Fixes

* ensure streams are always closed ([76fd1df](https://github.com/deeprails/deeprails-sdk-python/commit/76fd1dfa0d8ccfe9fbb2046882cf737b5ca6c865))


### Chores

* add Python 3.14 classifier and testing ([87c660e](https://github.com/deeprails/deeprails-sdk-python/commit/87c660e69f8509666d20a67a8cbabcd63aa67325))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([5d9ceab](https://github.com/deeprails/deeprails-sdk-python/commit/5d9ceabb224e620221a162a0fc56812629f5b2d7))
* **docs:** use environment variables for authentication in code snippets ([05bf7de](https://github.com/deeprails/deeprails-sdk-python/commit/05bf7de49c385433a792058e1d40474840ff3b87))
* update lockfile ([38655f6](https://github.com/deeprails/deeprails-sdk-python/commit/38655f6e1b8f9984e9bc2256a80b7018fa28b295))

## 1.20.0 (2025-11-20)

Full Changelog: [v1.19.0...v1.20.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.19.0...v1.20.0)

### Features

* **api:** fix files upload parameter ([a3e0a11](https://github.com/deeprails/deeprails-sdk-python/commit/a3e0a118e36ae4e4133b42ed57e74692d8052d8f))

## 1.19.0 (2025-11-19)

Full Changelog: [v1.18.0...v1.19.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.18.0...v1.19.0)

### Features

* **api:** Minor changes and updates to examples ([804c8be](https://github.com/deeprails/deeprails-sdk-python/commit/804c8bea03fa1f8cbee47e0858a04ba88cce3d8f))
* **api:** Update pyproject.toml ([4ed51b6](https://github.com/deeprails/deeprails-sdk-python/commit/4ed51b6c313d8a77ec1c9b685b90df8dc1840194))

## 1.18.0 (2025-11-19)

Full Changelog: [v1.17.0...v1.18.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.17.0...v1.18.0)

### Features

* **api:** update package name casing ([0173666](https://github.com/deeprails/deeprails-sdk-python/commit/0173666c5971633c10221bbb0d4962fac233ce48))

## 1.17.0 (2025-11-18)

Full Changelog: [v1.16.0...v1.17.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.16.0...v1.17.0)

### Features

* **api:** revert docs URL ([17ce0e7](https://github.com/deeprails/deeprails-sdk-python/commit/17ce0e774049a9140cb20d6a4994820e70cf5911))

## 1.16.0 (2025-11-18)

Full Changelog: [v1.15.0...v1.16.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.15.0...v1.16.0)

### Features

* **api:** update docs URL ([587d5fb](https://github.com/deeprails/deeprails-sdk-python/commit/587d5fbc58e5bec2f89ee8c48f9815b4cb169caa))

## 1.15.0 (2025-11-12)

Full Changelog: [v1.14.0...v1.15.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.14.0...v1.15.0)

### Features

* **api:** remove dev server ([aee58f7](https://github.com/deeprails/deeprails-sdk-python/commit/aee58f7a369729f5b50030f722a02b6da9abd88c))


### Bug Fixes

* compat with Python 3.14 ([f319169](https://github.com/deeprails/deeprails-sdk-python/commit/f319169022a0fe5992e335dc63a00c9bc47d95d8))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([02e642b](https://github.com/deeprails/deeprails-sdk-python/commit/02e642b8fa4f10e49014187ae8887a4dcc1f8a66))


### Chores

* **package:** drop Python 3.8 support ([25663d6](https://github.com/deeprails/deeprails-sdk-python/commit/25663d6698f6b61125f60d5fc0ba8a0ec26a800c))

## 1.14.0 (2025-11-11)

Full Changelog: [v1.13.0...v1.14.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.13.0...v1.14.0)

### Features

* **api:** add retrieve monitor event and examples ([b295221](https://github.com/deeprails/deeprails-sdk-python/commit/b2952212f394e8947c900735a5841b78bf8ec729))

## 1.13.0 (2025-11-10)

Full Changelog: [v1.12.0...v1.13.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.12.0...v1.13.0)

### Features

* **api:** Mass restructuring of API, including response bodies and naming schemes ([c72cf32](https://github.com/deeprails/deeprails-sdk-python/commit/c72cf32b37a41673c895a172dd09dcbe90b6ce40))


### Chores

* **internal:** grammar fix (it's -&gt; its) ([11449b2](https://github.com/deeprails/deeprails-sdk-python/commit/11449b27a513a1c5b5b35ba88778c636582feb0b))

## 1.12.0 (2025-11-02)

Full Changelog: [v1.11.0...v1.12.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.11.0...v1.12.0)

### Features

* **api:** restructure monitor service ([47cac0a](https://github.com/deeprails/deeprails-sdk-python/commit/47cac0a5568f3f73619ccb34e701901468dffbd0))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([0413192](https://github.com/deeprails/deeprails-sdk-python/commit/0413192c31932a21cd34cc4fe63669914a1d1de3))

## 1.11.0 (2025-10-30)

Full Changelog: [v1.10.0...v1.11.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.10.0...v1.11.0)

### Features

* **api:** Add file and web search as extended ai capabilities ([fc2bb8d](https://github.com/deeprails/deeprails-sdk-python/commit/fc2bb8d0ce8f111279583398469ae9bc0d11d474))
* **api:** manual updates ([236c2a9](https://github.com/deeprails/deeprails-sdk-python/commit/236c2a923f7bcaa08f92a799be9ca725a0a3b53b))


### Bug Fixes

* **client:** close streams without requiring full consumption ([db832f6](https://github.com/deeprails/deeprails-sdk-python/commit/db832f6e4067940c762e5d0be9d57cbaf72c7309))

## 1.10.0 (2025-10-29)

Full Changelog: [v1.9.0...v1.10.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.9.0...v1.10.0)

### Features

* **api:** remove evaluate api ([a3ddec1](https://github.com/deeprails/deeprails-sdk-python/commit/a3ddec1696eaa1247eea2a3bffd61e63d6537d30))
* **api:** remove evaluate references ([23519a3](https://github.com/deeprails/deeprails-sdk-python/commit/23519a3349a254fe2fe24a51aeb59545d0820b70))

## 1.9.0 (2025-10-24)

Full Changelog: [v1.8.0...v1.9.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.8.0...v1.9.0)

### Features

* **api:** remove apiresponse from monitor ([4971a99](https://github.com/deeprails/deeprails-sdk-python/commit/4971a99c7357bebbc5e86a2d76d2be55bb34f5ae))

## 1.8.0 (2025-10-22)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.7.0...v1.8.0)

### Features

* **api:** manual updates ([4b46121](https://github.com/deeprails/deeprails-sdk-python/commit/4b461213615578ca0382f044201c8343d4e9f167))

## 1.7.0 (2025-10-22)

Full Changelog: [v1.6.1...v1.7.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.6.1...v1.7.0)

### Features

* **api:** update defend naming and data structures ([ba934de](https://github.com/deeprails/deeprails-sdk-python/commit/ba934de8812d71da159a00fa8283876e682aeb7b))

## 1.6.1 (2025-10-22)

Full Changelog: [v1.6.0...v1.6.1](https://github.com/deeprails/deeprails-sdk-python/compare/v1.6.0...v1.6.1)

### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([fde0f65](https://github.com/deeprails/deeprails-sdk-python/commit/fde0f65f5947336baeee5ae71d7ad49fa8aefc98))

## 1.6.0 (2025-10-20)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.5.0...v1.6.0)

### Features

* **api:** readme example update ([412839e](https://github.com/deeprails/deeprails-sdk-python/commit/412839e484bcc4b216b88ea3f22849dc9355b643))

## 1.5.0 (2025-10-16)

Full Changelog: [v1.4.1...v1.5.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.4.1...v1.5.0)

### Features

* **api:** adding support for system_prompt and ground_truth ([be4cd74](https://github.com/deeprails/deeprails-sdk-python/commit/be4cd74a118dc1e4b1ef90f25f311a0862807176))

## 1.4.1 (2025-10-11)

Full Changelog: [v1.4.0...v1.4.1](https://github.com/deeprails/deeprails-sdk-python/compare/v1.4.0...v1.4.1)

### Chores

* **internal:** detect missing future annotations with ruff ([c0b084c](https://github.com/deeprails/deeprails-sdk-python/commit/c0b084c0f0e71a600274186c30902246aa3816d1))

## 1.4.0 (2025-10-10)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** manual updates ([b6beebc](https://github.com/deeprails/deeprails-sdk-python/commit/b6beebca6323df5ae35ef30d419d96c831bebbb8))

## 1.3.0 (2025-10-08)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** adding code samples ([c7f7565](https://github.com/deeprails/deeprails-sdk-python/commit/c7f7565abd00233d22d9c11a5b2c977414e03439))
* **api:** manual updates ([145946a](https://github.com/deeprails/deeprails-sdk-python/commit/145946a049fb29bff01df6763248330f4d0030ad))

## 1.2.0 (2025-10-07)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** manual updates ([db3e710](https://github.com/deeprails/deeprails-sdk-python/commit/db3e710d267ccf8d99aa214348846e20b6484db6))

## 1.1.0 (2025-10-07)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/deeprails/deeprails-sdk-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** manual updates ([e55683b](https://github.com/deeprails/deeprails-sdk-python/commit/e55683b590ff636e7c876a172c22c52c3208ceda))
* **api:** manual updates ([3309c85](https://github.com/deeprails/deeprails-sdk-python/commit/3309c859f9e67579bcd9d2f2d82ed7d67609dca8))


### Chores

* update SDK settings ([9b65ba6](https://github.com/deeprails/deeprails-sdk-python/commit/9b65ba6e8675011f89f035d608a404d7c1d50453))
* update SDK settings ([957c361](https://github.com/deeprails/deeprails-sdk-python/commit/957c3611f3baf773270a491c66a28b8eeb66d671))
* update SDK settings ([3dcb5cb](https://github.com/deeprails/deeprails-sdk-python/commit/3dcb5cb41ee6c1008f66dace32125fd38626bdca))
* update SDK settings ([b283586](https://github.com/deeprails/deeprails-sdk-python/commit/b28358658ea8cbea0d2cb679343a9cf1c342fbd2))

## 1.0.0 (2025-10-07)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/deeprails/deeprails-python-sdk/compare/v0.0.1...v1.0.0)

### Chores

* update SDK settings ([3dcb5cb](https://github.com/deeprails/deeprails-python-sdk/commit/3dcb5cb41ee6c1008f66dace32125fd38626bdca))
* update SDK settings ([b283586](https://github.com/deeprails/deeprails-python-sdk/commit/b28358658ea8cbea0d2cb679343a9cf1c342fbd2))
